@@ -111,6 +111,7 @@ class App:
     PropertyPythonObject = 'App::PropertyPythonObject'
     PropertyQuantity = 'App::PropertyQuantity'
     PropertyQuantityConstraint = 'App::PropertyQuantityConstraint'
+    PropertyRotation = 'App::PropertyRotation'
     PropertySpeed = 'App::PropertySpeed'
     PropertyString = 'App::PropertyString'
     PropertyStringList = 'App::PropertyStringList'
@@ -189,6 +190,7 @@ class Common:
     MayaGestureNavigationStyle = 'MayaGestureNavigationStyle'
     NavigationStyle = 'NavigationStyle'
     OpenCascadeNavigationStyle = 'OpenCascadeNavigationStyle'
+    OpenSCADNavigationStyle = 'OpenSCADNavigationStyle'
     PathSelectionObserver = 'PathSelectionObserver'
     PropertyAngleItem = 'PropertyAngleItem'
     PropertyBoolItem = 'PropertyBoolItem'
@@ -213,6 +215,7 @@ class Common:
     PropertyPlacementItem = 'PropertyPlacementItem'
     PropertyPositionItem = 'PropertyPositionItem'
     PropertyPrecisionItem = 'PropertyPrecisionItem'
+    PropertyRotationItem = 'PropertyRotationItem'
     PropertySeparatorItem = 'PropertySeparatorItem'
     PropertyStringItem = 'PropertyStringItem'
     PropertyStringListItem = 'PropertyStringListItem'
